@@ -3,16 +3,25 @@
 
 #include "network/networkcontroller.h"
 
+#include <QDesktopServices>
+#include <QNetworkProxyFactory>
+
 #include "account/abstractaccount.h"
 #include "account/accountmanager.h"
 #include "config.h"
 #include "tokodon_http_debug.h"
+#include "utils/navigation.h"
+#include "utils/texthandler.h"
 
 using namespace Qt::Literals::StringLiterals;
 
 NetworkController::NetworkController(QObject *parent)
     : QObject(parent)
 {
+    // Save the original system-level proxy settings
+    m_systemHttpProxy = qgetenv("http_proxy");
+    m_systemHttpsProxy = qgetenv("https_proxy");
+
     setApplicationProxy();
 
     connect(&AccountManager::instance(), &AccountManager::accountsReady, this, [=] {
@@ -20,7 +29,7 @@ NetworkController::NetworkController(QObject *parent)
         openLink();
 
         if (!m_storedComposedText.isEmpty()) {
-            Q_EMIT openComposer(m_storedComposedText);
+            Q_EMIT Navigation::instance().openComposer(m_storedComposedText);
             m_storedComposedText.clear();
         }
     });
@@ -38,6 +47,18 @@ void NetworkController::setApplicationProxy()
     Config *cfg = Config::self();
     QNetworkProxy proxy;
 
+    // define network proxy environment variable
+    // this is needed for the media backends which don't obey qt's settings
+    QByteArray appProxy;
+    if (!cfg->proxyUser().isEmpty()) {
+        appProxy += QUrl::toPercentEncoding(cfg->proxyUser());
+        if (!cfg->proxyPassword().isEmpty()) {
+            appProxy += ":" + QUrl::toPercentEncoding(cfg->proxyPassword());
+        }
+        appProxy += "@";
+    }
+    appProxy += cfg->proxyHost().toLocal8Bit() + ":" + QByteArray::number(cfg->proxyPort());
+
     // type match to ProxyType from config.kcfg
     switch (cfg->proxyType()) {
     case 1: // HTTP
@@ -46,6 +67,12 @@ void NetworkController::setApplicationProxy()
         proxy.setPort(cfg->proxyPort());
         proxy.setUser(cfg->proxyUser());
         proxy.setPassword(cfg->proxyPassword());
+        QNetworkProxy::setApplicationProxy(proxy);
+
+        // also set it through environment variables for the media backends
+        appProxy.prepend("http://");
+        qputenv("http_proxy", appProxy);
+        qputenv("https_proxy", appProxy);
         break;
     case 2: // SOCKS 5
         proxy.setType(QNetworkProxy::Socks5Proxy);
@@ -53,15 +80,39 @@ void NetworkController::setApplicationProxy()
         proxy.setPort(cfg->proxyPort());
         proxy.setUser(cfg->proxyUser());
         proxy.setPassword(cfg->proxyPassword());
+        QNetworkProxy::setApplicationProxy(proxy);
+
+        // also set it through environment variables for the media backends
+        appProxy.prepend("socks5://");
+        qputenv("http_proxy", appProxy);
+        qputenv("https_proxy", appProxy);
+        break;
+    case 3:
+        proxy.setType(QNetworkProxy::NoProxy);
+        QNetworkProxy::setApplicationProxy(proxy);
+
+        // also reset environment variables if they have been set
+        qunsetenv("http_proxy");
+        qunsetenv("https_proxy");
         break;
     case 0: // System Default
     default:
-        // do nothing
+        QNetworkProxyFactory::setUseSystemConfiguration(true);
+
+        // also reset env variables that might have been overridden
+        if (!m_systemHttpProxy.isEmpty()) {
+            qputenv("http_proxy", m_systemHttpProxy);
+        } else {
+            qunsetenv("http_proxy");
+        }
+        if (!m_systemHttpProxy.isEmpty()) {
+            qputenv("https_proxy", m_systemHttpsProxy);
+        } else {
+            qunsetenv("https_proxy");
+        }
         break;
     }
 
-    QNetworkProxy::setApplicationProxy(proxy);
-
     AccountManager::instance().reloadAccounts();
 }
 
@@ -115,11 +166,11 @@ void NetworkController::openLink()
         QString path = m_requestedLink.path();
         path.remove(0, path.lastIndexOf(QLatin1Char('/')) + 1);
 
-        Q_EMIT NetworkController::instance().openPost(path);
+        Q_EMIT Navigation::instance().openPost(path);
         return;
     }
 
-    requestRemoteObject(account, m_requestedLink.toString(), [=](QNetworkReply *reply) {
+    account->requestRemoteObject(m_requestedLink, account, [=](QNetworkReply *reply) {
         const auto searchResult = QJsonDocument::fromJson(reply->readAll()).object();
 
         const auto statuses = searchResult[QStringLiteral("statuses")].toArray();
@@ -130,7 +181,7 @@ void NetworkController::openLink()
         } else {
             const auto status = statuses[0].toObject();
 
-            Q_EMIT NetworkController::instance().openPost(status["id"_L1].toString());
+            Q_EMIT Navigation::instance().openPost(status["id"_L1].toString());
         }
 
         if (accounts.isEmpty()) {
@@ -138,7 +189,7 @@ void NetworkController::openLink()
         } else {
             const auto account = accounts[0].toObject();
 
-            Q_EMIT NetworkController::instance().openAccount(account["id"_L1].toString());
+            Q_EMIT Navigation::instance().openAccount(account["id"_L1].toString());
         }
 
         m_requestedLink.clear();
@@ -148,26 +199,39 @@ void NetworkController::openLink()
 void NetworkController::startComposing(const QString &text)
 {
     if (m_accountsReady) {
-        Q_EMIT openComposer(text);
+        Q_EMIT Navigation::instance().openComposer(text);
     } else {
         m_storedComposedText = text;
     }
 }
 
-void NetworkController::requestRemoteObject(AbstractAccount *account, const QString &remoteUrl, std::function<void(QNetworkReply *)> callback)
-{
-    auto url = account->apiUrl(QStringLiteral("/api/v2/search"));
-    url.setQuery({
-        {QStringLiteral("q"), remoteUrl},
-        {QStringLiteral("resolve"), QStringLiteral("true")},
-        {QStringLiteral("limit"), QStringLiteral("1")},
-    });
-    account->get(url, true, &AccountManager::instance(), std::move(callback));
-}
-
 bool NetworkController::pushNotificationsAvailable() const
 {
     return !endpoint.isEmpty();
 }
 
-#include "moc_networkcontroller.cpp"
\ No newline at end of file
+void NetworkController::openLink(const QString &input)
+{
+    // TODO: expand to profiles?
+    if (TextHandler::isPostUrl(input)) {
+        auto account = AccountManager::instance().selectedAccount();
+
+        // Then request said URL from our server
+        account->requestRemoteObject(QUrl(input), account, [=](QNetworkReply *reply) {
+            const auto searchResult = QJsonDocument::fromJson(reply->readAll()).object();
+
+            const auto statuses = searchResult[QStringLiteral("statuses")].toArray();
+
+            if (!statuses.isEmpty()) {
+                Navigation::instance().openPost(statuses.last()[QStringLiteral("id")].toString());
+            } else {
+                // worst case, open it in a web browser
+                QDesktopServices::openUrl(QUrl::fromUserInput(input));
+            }
+        });
+    } else {
+        QDesktopServices::openUrl(QUrl::fromUserInput(input));
+    }
+}
+
+#include "moc_networkcontroller.cpp"
