@@ -7,7 +7,6 @@
 #include "utils/filetransferjob.h"
 
 #ifdef HAVE_KIO
-#include <KIO/Job>
 #include <KIO/JobTracker>
 #include <KJobTrackerInterface>
 #endif
@@ -28,20 +27,9 @@ void FileHelper::downloadFile(AbstractAccount *account, const QString &url, cons
     job->start();
 }
 
-QString FileHelper::url(const QUrl &url) const
-{
-    return url.fileName().split(QLatin1Char('.')).last();
-}
-
 QString FileHelper::fileName(const QUrl &url) const
 {
     return url.fileName();
 }
 
-void FileHelper::forceRefreshTextDocument(QQuickTextDocument *textDocument, QQuickItem *item)
-{
-    // HACK: Workaround bug QTBUG 93281
-    connect(textDocument->textDocument(), SIGNAL(imagesLoaded()), item, SLOT(updateWholeDocument()));
-}
-
 #include "moc_filehelper.cpp"
